# Damage
This library provides utilities to apply custom damage to entities and players.

[Documentation](https://wiki.smithed.dev/libraries/smithed-core/entities/score-based-damage)


## Downloading
You can download it from [here](https://smithed.dev/thenuclearnexus/smithed-damage)<br/>
or<br/>
You can build it from source using the [beet](https://github.com/mcbeet/beet)

### Building
```
$ pip install beet mecha
$ git clone https://github.com/Smithed-MC/Libraries
$ cd Libraries/damage
$ beet build
```
